==> haskell-cassava-megaparsec-2.1.1-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-9gFrcsjViza7XS9yzpko0L
key:                  cassava-megaparsec-2.1.1-9gFrcsjViza7XS9yzpko0L
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  33ec3a24db6c30af992d4c512bdc37bb
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-9gFrcsjViza7XS9yzpko0L
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cassava-0.5.3.1-8LsCy3OXFmZIYiiCdVvjyw
    megaparsec-9.5.0-Jwu5LIKr9Z8JTb6Qjv9hi0
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.1.1-17-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-H6jB8Dk3aQX2u6I3NqQxy3
key:                  cassava-megaparsec-2.1.1-H6jB8Dk3aQX2u6I3NqQxy3
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  0e99325c54b62f16724051beb551ca1d
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-H6jB8Dk3aQX2u6I3NqQxy3
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cassava-0.5.3.1-Azaklg4BLTk4uaygxKQViU
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
